@@ -1,6 +1,6 @@
 from enum import Enum
 
-VERSIONS = ("1.0", "1.1", "1.2", "1.3", "1.4")
+VERSIONS = ("1.0", "1.1", "1.2", "1.3", "1.4", "1.5")
 SCHEMA = "http://adaptivecards.io/schemas/adaptive-card.json"
 
 
@@ -92,9 +92,15 @@ class ActionStyle(str, Enum):
     DESTRUCTIVE = "destructive"
 
 
+class ActionMode(str, Enum):
+    PRIMARY = "primary"
+    SECONDARY = "secondary"
+
+
 class ChoiceInputStyle(str, Enum):
     COMPACT = "compact"
     EXPANDED = "expanded"
+    FILTERED = "filtered"
 
 
 class TextInputStyle(str, Enum):
@@ -102,6 +108,7 @@ class TextInputStyle(str, Enum):
     TEL = "tel"
     URL = "url"
     EMAIL = "email"
+    PASSWORD = "password"
 
 
 class Width(str, Enum):
